from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException
from pdf4me.model import Merge


class MergeClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def merge(self, merge):
        """The predefined merge is carried out.

        :param merge: merge configuration
        :type merge: Merge
        :return: MergeRes, contains merged PDF
        """

        # check merge validity
        self.__check_merge_object_validity(merge)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=merge,
                                                                   controller='Merge/Merge')

        return res

    def merge_2_pdfs(self, file1, file2):
        """Merges the two provided PDF files.

        :param file1: first PDF
        :type file1: file handler, use the method get_file_handler from FileReader to obtain it
        :param file2: second PDF
        :type file2: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file1', file1), ('file2', file2)]
        params = []

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='Merge/Merge2Pdfs')

    def __check_merge_object_validity(self, merge):
        """Checks whether the merge object contains the essential information to be
        processed by the server."""

        if merge is None:
            raise Pdf4meClientException('The merge parameter cannot be None.')
        elif merge.documents is None:
            raise Pdf4meClientException('The merge documents cannot be None.')
        elif merge.merge_action is None:
            raise Pdf4meClientException('The merge_action cannot be None.')

        numDocs = len(merge.documents)
        # check whether there are at least two documents
        if numDocs < 2:
            raise Pdf4meClientException('The merge documents must contain at least two documents.')
        # check whether all documents are not undefined neither is their docData
        docs = merge.documents
        for i in range(numDocs):
            currentDoc = docs[i]
            if currentDoc is None or currentDoc.doc_data is None:
                raise Pdf4meClientException('The merge documents cannot be None nor can the document.docData.')



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class UsageSubscription(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'subscription_id': 'str',
        'sub_cost_total': 'int',
        'sub_cost_current': 'int',
        'api_cost_total': 'int',
        'api_cost_current': 'int',
        'feature': 'str',
        'feature_call_cnt': 'int',
        'duration_ms_avg': 'int',
        'duration_ms_min': 'int',
        'duration_ms_max': 'int',
        'pages_avg': 'int',
        'pages_min': 'int',
        'pages_max': 'int',
        'pages_sum': 'int',
        'doc_size_avg': 'int',
        'doc_size_min': 'int',
        'doc_size_max': 'int',
        'doc_size_sum': 'int',
        'time_stamp_from': 'datetime',
        'time_stamp_to': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'subscription_id': 'subscriptionId',
        'sub_cost_total': 'subCostTotal',
        'sub_cost_current': 'subCostCurrent',
        'api_cost_total': 'apiCostTotal',
        'api_cost_current': 'apiCostCurrent',
        'feature': 'feature',
        'feature_call_cnt': 'featureCallCnt',
        'duration_ms_avg': 'durationMsAvg',
        'duration_ms_min': 'durationMsMin',
        'duration_ms_max': 'durationMsMax',
        'pages_avg': 'pagesAvg',
        'pages_min': 'pagesMin',
        'pages_max': 'pagesMax',
        'pages_sum': 'pagesSum',
        'doc_size_avg': 'docSizeAvg',
        'doc_size_min': 'docSizeMin',
        'doc_size_max': 'docSizeMax',
        'doc_size_sum': 'docSizeSum',
        'time_stamp_from': 'timeStampFrom',
        'time_stamp_to': 'timeStampTo'
    }

    def __init__(self, id=None, subscription_id=None, sub_cost_total=None, sub_cost_current=None, api_cost_total=None, api_cost_current=None, feature=None, feature_call_cnt=None, duration_ms_avg=None, duration_ms_min=None, duration_ms_max=None, pages_avg=None, pages_min=None, pages_max=None, pages_sum=None, doc_size_avg=None, doc_size_min=None, doc_size_max=None, doc_size_sum=None, time_stamp_from=None, time_stamp_to=None):  # noqa: E501
        """UsageSubscription - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._subscription_id = None
        self._sub_cost_total = None
        self._sub_cost_current = None
        self._api_cost_total = None
        self._api_cost_current = None
        self._feature = None
        self._feature_call_cnt = None
        self._duration_ms_avg = None
        self._duration_ms_min = None
        self._duration_ms_max = None
        self._pages_avg = None
        self._pages_min = None
        self._pages_max = None
        self._pages_sum = None
        self._doc_size_avg = None
        self._doc_size_min = None
        self._doc_size_max = None
        self._doc_size_sum = None
        self._time_stamp_from = None
        self._time_stamp_to = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if subscription_id is not None:
            self.subscription_id = subscription_id
        if sub_cost_total is not None:
            self.sub_cost_total = sub_cost_total
        if sub_cost_current is not None:
            self.sub_cost_current = sub_cost_current
        if api_cost_total is not None:
            self.api_cost_total = api_cost_total
        if api_cost_current is not None:
            self.api_cost_current = api_cost_current
        if feature is not None:
            self.feature = feature
        if feature_call_cnt is not None:
            self.feature_call_cnt = feature_call_cnt
        if duration_ms_avg is not None:
            self.duration_ms_avg = duration_ms_avg
        if duration_ms_min is not None:
            self.duration_ms_min = duration_ms_min
        if duration_ms_max is not None:
            self.duration_ms_max = duration_ms_max
        if pages_avg is not None:
            self.pages_avg = pages_avg
        if pages_min is not None:
            self.pages_min = pages_min
        if pages_max is not None:
            self.pages_max = pages_max
        if pages_sum is not None:
            self.pages_sum = pages_sum
        if doc_size_avg is not None:
            self.doc_size_avg = doc_size_avg
        if doc_size_min is not None:
            self.doc_size_min = doc_size_min
        if doc_size_max is not None:
            self.doc_size_max = doc_size_max
        if doc_size_sum is not None:
            self.doc_size_sum = doc_size_sum
        if time_stamp_from is not None:
            self.time_stamp_from = time_stamp_from
        if time_stamp_to is not None:
            self.time_stamp_to = time_stamp_to

    @property
    def id(self):
        """Gets the id of this UsageSubscription.  # noqa: E501


        :return: The id of this UsageSubscription.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UsageSubscription.


        :param id: The id of this UsageSubscription.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def subscription_id(self):
        """Gets the subscription_id of this UsageSubscription.  # noqa: E501


        :return: The subscription_id of this UsageSubscription.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this UsageSubscription.


        :param subscription_id: The subscription_id of this UsageSubscription.  # noqa: E501
        :type: str
        """

        self._subscription_id = subscription_id

    @property
    def sub_cost_total(self):
        """Gets the sub_cost_total of this UsageSubscription.  # noqa: E501


        :return: The sub_cost_total of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._sub_cost_total

    @sub_cost_total.setter
    def sub_cost_total(self, sub_cost_total):
        """Sets the sub_cost_total of this UsageSubscription.


        :param sub_cost_total: The sub_cost_total of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._sub_cost_total = sub_cost_total

    @property
    def sub_cost_current(self):
        """Gets the sub_cost_current of this UsageSubscription.  # noqa: E501


        :return: The sub_cost_current of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._sub_cost_current

    @sub_cost_current.setter
    def sub_cost_current(self, sub_cost_current):
        """Sets the sub_cost_current of this UsageSubscription.


        :param sub_cost_current: The sub_cost_current of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._sub_cost_current = sub_cost_current

    @property
    def api_cost_total(self):
        """Gets the api_cost_total of this UsageSubscription.  # noqa: E501


        :return: The api_cost_total of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._api_cost_total

    @api_cost_total.setter
    def api_cost_total(self, api_cost_total):
        """Sets the api_cost_total of this UsageSubscription.


        :param api_cost_total: The api_cost_total of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._api_cost_total = api_cost_total

    @property
    def api_cost_current(self):
        """Gets the api_cost_current of this UsageSubscription.  # noqa: E501


        :return: The api_cost_current of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._api_cost_current

    @api_cost_current.setter
    def api_cost_current(self, api_cost_current):
        """Sets the api_cost_current of this UsageSubscription.


        :param api_cost_current: The api_cost_current of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._api_cost_current = api_cost_current

    @property
    def feature(self):
        """Gets the feature of this UsageSubscription.  # noqa: E501


        :return: The feature of this UsageSubscription.  # noqa: E501
        :rtype: str
        """
        return self._feature

    @feature.setter
    def feature(self, feature):
        """Sets the feature of this UsageSubscription.


        :param feature: The feature of this UsageSubscription.  # noqa: E501
        :type: str
        """

        self._feature = feature

    @property
    def feature_call_cnt(self):
        """Gets the feature_call_cnt of this UsageSubscription.  # noqa: E501


        :return: The feature_call_cnt of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._feature_call_cnt

    @feature_call_cnt.setter
    def feature_call_cnt(self, feature_call_cnt):
        """Sets the feature_call_cnt of this UsageSubscription.


        :param feature_call_cnt: The feature_call_cnt of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._feature_call_cnt = feature_call_cnt

    @property
    def duration_ms_avg(self):
        """Gets the duration_ms_avg of this UsageSubscription.  # noqa: E501


        :return: The duration_ms_avg of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._duration_ms_avg

    @duration_ms_avg.setter
    def duration_ms_avg(self, duration_ms_avg):
        """Sets the duration_ms_avg of this UsageSubscription.


        :param duration_ms_avg: The duration_ms_avg of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._duration_ms_avg = duration_ms_avg

    @property
    def duration_ms_min(self):
        """Gets the duration_ms_min of this UsageSubscription.  # noqa: E501


        :return: The duration_ms_min of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._duration_ms_min

    @duration_ms_min.setter
    def duration_ms_min(self, duration_ms_min):
        """Sets the duration_ms_min of this UsageSubscription.


        :param duration_ms_min: The duration_ms_min of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._duration_ms_min = duration_ms_min

    @property
    def duration_ms_max(self):
        """Gets the duration_ms_max of this UsageSubscription.  # noqa: E501


        :return: The duration_ms_max of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._duration_ms_max

    @duration_ms_max.setter
    def duration_ms_max(self, duration_ms_max):
        """Sets the duration_ms_max of this UsageSubscription.


        :param duration_ms_max: The duration_ms_max of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._duration_ms_max = duration_ms_max

    @property
    def pages_avg(self):
        """Gets the pages_avg of this UsageSubscription.  # noqa: E501


        :return: The pages_avg of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._pages_avg

    @pages_avg.setter
    def pages_avg(self, pages_avg):
        """Sets the pages_avg of this UsageSubscription.


        :param pages_avg: The pages_avg of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._pages_avg = pages_avg

    @property
    def pages_min(self):
        """Gets the pages_min of this UsageSubscription.  # noqa: E501


        :return: The pages_min of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._pages_min

    @pages_min.setter
    def pages_min(self, pages_min):
        """Sets the pages_min of this UsageSubscription.


        :param pages_min: The pages_min of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._pages_min = pages_min

    @property
    def pages_max(self):
        """Gets the pages_max of this UsageSubscription.  # noqa: E501


        :return: The pages_max of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._pages_max

    @pages_max.setter
    def pages_max(self, pages_max):
        """Sets the pages_max of this UsageSubscription.


        :param pages_max: The pages_max of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._pages_max = pages_max

    @property
    def pages_sum(self):
        """Gets the pages_sum of this UsageSubscription.  # noqa: E501


        :return: The pages_sum of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._pages_sum

    @pages_sum.setter
    def pages_sum(self, pages_sum):
        """Sets the pages_sum of this UsageSubscription.


        :param pages_sum: The pages_sum of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._pages_sum = pages_sum

    @property
    def doc_size_avg(self):
        """Gets the doc_size_avg of this UsageSubscription.  # noqa: E501


        :return: The doc_size_avg of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._doc_size_avg

    @doc_size_avg.setter
    def doc_size_avg(self, doc_size_avg):
        """Sets the doc_size_avg of this UsageSubscription.


        :param doc_size_avg: The doc_size_avg of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._doc_size_avg = doc_size_avg

    @property
    def doc_size_min(self):
        """Gets the doc_size_min of this UsageSubscription.  # noqa: E501


        :return: The doc_size_min of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._doc_size_min

    @doc_size_min.setter
    def doc_size_min(self, doc_size_min):
        """Sets the doc_size_min of this UsageSubscription.


        :param doc_size_min: The doc_size_min of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._doc_size_min = doc_size_min

    @property
    def doc_size_max(self):
        """Gets the doc_size_max of this UsageSubscription.  # noqa: E501


        :return: The doc_size_max of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._doc_size_max

    @doc_size_max.setter
    def doc_size_max(self, doc_size_max):
        """Sets the doc_size_max of this UsageSubscription.


        :param doc_size_max: The doc_size_max of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._doc_size_max = doc_size_max

    @property
    def doc_size_sum(self):
        """Gets the doc_size_sum of this UsageSubscription.  # noqa: E501


        :return: The doc_size_sum of this UsageSubscription.  # noqa: E501
        :rtype: int
        """
        return self._doc_size_sum

    @doc_size_sum.setter
    def doc_size_sum(self, doc_size_sum):
        """Sets the doc_size_sum of this UsageSubscription.


        :param doc_size_sum: The doc_size_sum of this UsageSubscription.  # noqa: E501
        :type: int
        """

        self._doc_size_sum = doc_size_sum

    @property
    def time_stamp_from(self):
        """Gets the time_stamp_from of this UsageSubscription.  # noqa: E501


        :return: The time_stamp_from of this UsageSubscription.  # noqa: E501
        :rtype: datetime
        """
        return self._time_stamp_from

    @time_stamp_from.setter
    def time_stamp_from(self, time_stamp_from):
        """Sets the time_stamp_from of this UsageSubscription.


        :param time_stamp_from: The time_stamp_from of this UsageSubscription.  # noqa: E501
        :type: datetime
        """

        self._time_stamp_from = time_stamp_from

    @property
    def time_stamp_to(self):
        """Gets the time_stamp_to of this UsageSubscription.  # noqa: E501


        :return: The time_stamp_to of this UsageSubscription.  # noqa: E501
        :rtype: datetime
        """
        return self._time_stamp_to

    @time_stamp_to.setter
    def time_stamp_to(self, time_stamp_to):
        """Sets the time_stamp_to of this UsageSubscription.


        :param time_stamp_to: The time_stamp_to of this UsageSubscription.  # noqa: E501
        :type: datetime
        """

        self._time_stamp_to = time_stamp_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UsageSubscription, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UsageSubscription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'title': 'str',
        'subject': 'str',
        'page_count': 'int',
        'author': 'str',
        'creator': 'str',
        'producer': 'str',
        'creation_date': 'datetime',
        'mod_date': 'datetime',
        'size': 'int',
        'is_encrypted': 'bool',
        'is_linearized': 'bool',
        'pdf_compliance': 'str',
        'is_signed': 'bool',
        'document_id': 'str'
    }

    attribute_map = {
        'title': 'title',
        'subject': 'subject',
        'page_count': 'pageCount',
        'author': 'author',
        'creator': 'creator',
        'producer': 'producer',
        'creation_date': 'creationDate',
        'mod_date': 'modDate',
        'size': 'size',
        'is_encrypted': 'isEncrypted',
        'is_linearized': 'isLinearized',
        'pdf_compliance': 'pdfCompliance',
        'is_signed': 'isSigned',
        'document_id': 'documentId'
    }

    def __init__(self, title=None, subject=None, page_count=None, author=None, creator=None, producer=None, creation_date=None, mod_date=None, size=None, is_encrypted=None, is_linearized=None, pdf_compliance=None, is_signed=None, document_id=None):  # noqa: E501
        """DocMetadata - a model defined in Swagger"""  # noqa: E501

        self._title = None
        self._subject = None
        self._page_count = None
        self._author = None
        self._creator = None
        self._producer = None
        self._creation_date = None
        self._mod_date = None
        self._size = None
        self._is_encrypted = None
        self._is_linearized = None
        self._pdf_compliance = None
        self._is_signed = None
        self._document_id = None
        self.discriminator = None

        if title is not None:
            self.title = title
        if subject is not None:
            self.subject = subject
        if page_count is not None:
            self.page_count = page_count
        if author is not None:
            self.author = author
        if creator is not None:
            self.creator = creator
        if producer is not None:
            self.producer = producer
        if creation_date is not None:
            self.creation_date = creation_date
        if mod_date is not None:
            self.mod_date = mod_date
        if size is not None:
            self.size = size
        if is_encrypted is not None:
            self.is_encrypted = is_encrypted
        if is_linearized is not None:
            self.is_linearized = is_linearized
        if pdf_compliance is not None:
            self.pdf_compliance = pdf_compliance
        if is_signed is not None:
            self.is_signed = is_signed
        if document_id is not None:
            self.document_id = document_id

    @property
    def title(self):
        """Gets the title of this DocMetadata.  # noqa: E501


        :return: The title of this DocMetadata.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this DocMetadata.


        :param title: The title of this DocMetadata.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def subject(self):
        """Gets the subject of this DocMetadata.  # noqa: E501


        :return: The subject of this DocMetadata.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this DocMetadata.


        :param subject: The subject of this DocMetadata.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def page_count(self):
        """Gets the page_count of this DocMetadata.  # noqa: E501


        :return: The page_count of this DocMetadata.  # noqa: E501
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """Sets the page_count of this DocMetadata.


        :param page_count: The page_count of this DocMetadata.  # noqa: E501
        :type: int
        """

        self._page_count = page_count

    @property
    def author(self):
        """Gets the author of this DocMetadata.  # noqa: E501


        :return: The author of this DocMetadata.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this DocMetadata.


        :param author: The author of this DocMetadata.  # noqa: E501
        :type: str
        """

        self._author = author

    @property
    def creator(self):
        """Gets the creator of this DocMetadata.  # noqa: E501


        :return: The creator of this DocMetadata.  # noqa: E501
        :rtype: str
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this DocMetadata.


        :param creator: The creator of this DocMetadata.  # noqa: E501
        :type: str
        """

        self._creator = creator

    @property
    def producer(self):
        """Gets the producer of this DocMetadata.  # noqa: E501


        :return: The producer of this DocMetadata.  # noqa: E501
        :rtype: str
        """
        return self._producer

    @producer.setter
    def producer(self, producer):
        """Sets the producer of this DocMetadata.


        :param producer: The producer of this DocMetadata.  # noqa: E501
        :type: str
        """

        self._producer = producer

    @property
    def creation_date(self):
        """Gets the creation_date of this DocMetadata.  # noqa: E501


        :return: The creation_date of this DocMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this DocMetadata.


        :param creation_date: The creation_date of this DocMetadata.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def mod_date(self):
        """Gets the mod_date of this DocMetadata.  # noqa: E501


        :return: The mod_date of this DocMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._mod_date

    @mod_date.setter
    def mod_date(self, mod_date):
        """Sets the mod_date of this DocMetadata.


        :param mod_date: The mod_date of this DocMetadata.  # noqa: E501
        :type: datetime
        """

        self._mod_date = mod_date

    @property
    def size(self):
        """Gets the size of this DocMetadata.  # noqa: E501


        :return: The size of this DocMetadata.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this DocMetadata.


        :param size: The size of this DocMetadata.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def is_encrypted(self):
        """Gets the is_encrypted of this DocMetadata.  # noqa: E501


        :return: The is_encrypted of this DocMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._is_encrypted

    @is_encrypted.setter
    def is_encrypted(self, is_encrypted):
        """Sets the is_encrypted of this DocMetadata.


        :param is_encrypted: The is_encrypted of this DocMetadata.  # noqa: E501
        :type: bool
        """

        self._is_encrypted = is_encrypted

    @property
    def is_linearized(self):
        """Gets the is_linearized of this DocMetadata.  # noqa: E501


        :return: The is_linearized of this DocMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._is_linearized

    @is_linearized.setter
    def is_linearized(self, is_linearized):
        """Sets the is_linearized of this DocMetadata.


        :param is_linearized: The is_linearized of this DocMetadata.  # noqa: E501
        :type: bool
        """

        self._is_linearized = is_linearized

    @property
    def pdf_compliance(self):
        """Gets the pdf_compliance of this DocMetadata.  # noqa: E501


        :return: The pdf_compliance of this DocMetadata.  # noqa: E501
        :rtype: str
        """
        return self._pdf_compliance

    @pdf_compliance.setter
    def pdf_compliance(self, pdf_compliance):
        """Sets the pdf_compliance of this DocMetadata.


        :param pdf_compliance: The pdf_compliance of this DocMetadata.  # noqa: E501
        :type: str
        """

        self._pdf_compliance = pdf_compliance

    @property
    def is_signed(self):
        """Gets the is_signed of this DocMetadata.  # noqa: E501


        :return: The is_signed of this DocMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._is_signed

    @is_signed.setter
    def is_signed(self, is_signed):
        """Sets the is_signed of this DocMetadata.


        :param is_signed: The is_signed of this DocMetadata.  # noqa: E501
        :type: bool
        """

        self._is_signed = is_signed

    @property
    def document_id(self):
        """Gets the document_id of this DocMetadata.  # noqa: E501


        :return: The document_id of this DocMetadata.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this DocMetadata.


        :param document_id: The document_id of this DocMetadata.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DmsApi

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.user_fingerprint import UserFingerprint  # noqa: F401,E501


class GetDocumentReq(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'str',
        'document_id': 'str',
        'thumbnails_only': 'bool',
        'document_type': 'str',
        'get_notified': 'bool',
        'connection_id': 'str',
        'user_fingerprint': 'UserFingerprint'
    }

    attribute_map = {
        'job_id': 'jobId',
        'document_id': 'documentId',
        'thumbnails_only': 'thumbnailsOnly',
        'document_type': 'documentType',
        'get_notified': 'getNotified',
        'connection_id': 'connectionId',
        'user_fingerprint': 'userFingerprint'
    }

    def __init__(self, job_id=None, document_id=None, thumbnails_only=None, document_type=None, get_notified=None, connection_id=None, user_fingerprint=None):  # noqa: E501
        """GetDocumentReq - a model defined in Swagger"""  # noqa: E501

        self._job_id = None
        self._document_id = None
        self._thumbnails_only = None
        self._document_type = None
        self._get_notified = None
        self._connection_id = None
        self._user_fingerprint = None
        self.discriminator = None

        if job_id is not None:
            self.job_id = job_id
        if document_id is not None:
            self.document_id = document_id
        if thumbnails_only is not None:
            self.thumbnails_only = thumbnails_only
        if document_type is not None:
            self.document_type = document_type
        if get_notified is not None:
            self.get_notified = get_notified
        if connection_id is not None:
            self.connection_id = connection_id
        if user_fingerprint is not None:
            self.user_fingerprint = user_fingerprint

    @property
    def job_id(self):
        """Gets the job_id of this GetDocumentReq.  # noqa: E501


        :return: The job_id of this GetDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this GetDocumentReq.


        :param job_id: The job_id of this GetDocumentReq.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def document_id(self):
        """Gets the document_id of this GetDocumentReq.  # noqa: E501


        :return: The document_id of this GetDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this GetDocumentReq.


        :param document_id: The document_id of this GetDocumentReq.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def thumbnails_only(self):
        """Gets the thumbnails_only of this GetDocumentReq.  # noqa: E501


        :return: The thumbnails_only of this GetDocumentReq.  # noqa: E501
        :rtype: bool
        """
        return self._thumbnails_only

    @thumbnails_only.setter
    def thumbnails_only(self, thumbnails_only):
        """Sets the thumbnails_only of this GetDocumentReq.


        :param thumbnails_only: The thumbnails_only of this GetDocumentReq.  # noqa: E501
        :type: bool
        """

        self._thumbnails_only = thumbnails_only

    @property
    def document_type(self):
        """Gets the document_type of this GetDocumentReq.  # noqa: E501


        :return: The document_type of this GetDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """Sets the document_type of this GetDocumentReq.


        :param document_type: The document_type of this GetDocumentReq.  # noqa: E501
        :type: str
        """

        self._document_type = document_type

    @property
    def get_notified(self):
        """Gets the get_notified of this GetDocumentReq.  # noqa: E501

        Run the action asynchronously, get notified for any status changes.  # noqa: E501

        :return: The get_notified of this GetDocumentReq.  # noqa: E501
        :rtype: bool
        """
        return self._get_notified

    @get_notified.setter
    def get_notified(self, get_notified):
        """Sets the get_notified of this GetDocumentReq.

        Run the action asynchronously, get notified for any status changes.  # noqa: E501

        :param get_notified: The get_notified of this GetDocumentReq.  # noqa: E501
        :type: bool
        """

        self._get_notified = get_notified

    @property
    def connection_id(self):
        """Gets the connection_id of this GetDocumentReq.  # noqa: E501


        :return: The connection_id of this GetDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        """Sets the connection_id of this GetDocumentReq.


        :param connection_id: The connection_id of this GetDocumentReq.  # noqa: E501
        :type: str
        """

        self._connection_id = connection_id

    @property
    def user_fingerprint(self):
        """Gets the user_fingerprint of this GetDocumentReq.  # noqa: E501


        :return: The user_fingerprint of this GetDocumentReq.  # noqa: E501
        :rtype: UserFingerprint
        """
        return self._user_fingerprint

    @user_fingerprint.setter
    def user_fingerprint(self, user_fingerprint):
        """Sets the user_fingerprint of this GetDocumentReq.


        :param user_fingerprint: The user_fingerprint of this GetDocumentReq.  # noqa: E501
        :type: UserFingerprint
        """

        self._user_fingerprint = user_fingerprint

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetDocumentReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocLog(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message_type': 'str',
        'message': 'str',
        'timestamp': 'datetime',
        'doc_log_level': 'str',
        'duration_milliseconds': 'int'
    }

    attribute_map = {
        'message_type': 'messageType',
        'message': 'message',
        'timestamp': 'timestamp',
        'doc_log_level': 'docLogLevel',
        'duration_milliseconds': 'durationMilliseconds'
    }

    def __init__(self, message_type=None, message=None, timestamp=None, doc_log_level=None, duration_milliseconds=None):  # noqa: E501
        """DocLog - a model defined in Swagger"""  # noqa: E501

        self._message_type = None
        self._message = None
        self._timestamp = None
        self._doc_log_level = None
        self._duration_milliseconds = None
        self.discriminator = None

        if message_type is not None:
            self.message_type = message_type
        if message is not None:
            self.message = message
        if timestamp is not None:
            self.timestamp = timestamp
        if doc_log_level is not None:
            self.doc_log_level = doc_log_level
        if duration_milliseconds is not None:
            self.duration_milliseconds = duration_milliseconds

    @property
    def message_type(self):
        """Gets the message_type of this DocLog.  # noqa: E501


        :return: The message_type of this DocLog.  # noqa: E501
        :rtype: str
        """
        return self._message_type

    @message_type.setter
    def message_type(self, message_type):
        """Sets the message_type of this DocLog.


        :param message_type: The message_type of this DocLog.  # noqa: E501
        :type: str
        """

        self._message_type = message_type

    @property
    def message(self):
        """Gets the message of this DocLog.  # noqa: E501


        :return: The message of this DocLog.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this DocLog.


        :param message: The message of this DocLog.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def timestamp(self):
        """Gets the timestamp of this DocLog.  # noqa: E501


        :return: The timestamp of this DocLog.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this DocLog.


        :param timestamp: The timestamp of this DocLog.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    @property
    def doc_log_level(self):
        """Gets the doc_log_level of this DocLog.  # noqa: E501


        :return: The doc_log_level of this DocLog.  # noqa: E501
        :rtype: str
        """
        return self._doc_log_level

    @doc_log_level.setter
    def doc_log_level(self, doc_log_level):
        """Sets the doc_log_level of this DocLog.


        :param doc_log_level: The doc_log_level of this DocLog.  # noqa: E501
        :type: str
        """
        allowed_values = ["verbose", "info", "warning", "error", "timing"]  # noqa: E501
        if doc_log_level not in allowed_values:
            raise ValueError(
                "Invalid value for `doc_log_level` ({0}), must be one of {1}"  # noqa: E501
                .format(doc_log_level, allowed_values)
            )

        self._doc_log_level = doc_log_level

    @property
    def duration_milliseconds(self):
        """Gets the duration_milliseconds of this DocLog.  # noqa: E501


        :return: The duration_milliseconds of this DocLog.  # noqa: E501
        :rtype: int
        """
        return self._duration_milliseconds

    @duration_milliseconds.setter
    def duration_milliseconds(self, duration_milliseconds):
        """Sets the duration_milliseconds of this DocLog.


        :param duration_milliseconds: The duration_milliseconds of this DocLog.  # noqa: E501
        :type: int
        """

        self._duration_milliseconds = duration_milliseconds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocLog, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocLog):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Page(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'document_id': 'str',
        'page_id': 'str',
        'page_number': 'int',
        'rotate': 'float',
        'thumbnail': 'str',
        'page_url': 'str',
        'image_format': 'str'
    }

    attribute_map = {
        'document_id': 'documentId',
        'page_id': 'pageId',
        'page_number': 'pageNumber',
        'rotate': 'rotate',
        'thumbnail': 'thumbnail',
        'page_url': 'pageUrl',
        'image_format': 'imageFormat'
    }

    def __init__(self, document_id=None, page_id=None, page_number=None, rotate=None, thumbnail=None, page_url=None, image_format=None):  # noqa: E501
        """Page - a model defined in Swagger"""  # noqa: E501

        self._document_id = None
        self._page_id = None
        self._page_number = None
        self._rotate = None
        self._thumbnail = None
        self._page_url = None
        self._image_format = None
        self.discriminator = None

        if document_id is not None:
            self.document_id = document_id
        if page_id is not None:
            self.page_id = page_id
        if page_number is not None:
            self.page_number = page_number
        if rotate is not None:
            self.rotate = rotate
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if page_url is not None:
            self.page_url = page_url
        if image_format is not None:
            self.image_format = image_format

    @property
    def document_id(self):
        """Gets the document_id of this Page.  # noqa: E501


        :return: The document_id of this Page.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this Page.


        :param document_id: The document_id of this Page.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def page_id(self):
        """Gets the page_id of this Page.  # noqa: E501


        :return: The page_id of this Page.  # noqa: E501
        :rtype: str
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """Sets the page_id of this Page.


        :param page_id: The page_id of this Page.  # noqa: E501
        :type: str
        """

        self._page_id = page_id

    @property
    def page_number(self):
        """Gets the page_number of this Page.  # noqa: E501


        :return: The page_number of this Page.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this Page.


        :param page_number: The page_number of this Page.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def rotate(self):
        """Gets the rotate of this Page.  # noqa: E501


        :return: The rotate of this Page.  # noqa: E501
        :rtype: float
        """
        return self._rotate

    @rotate.setter
    def rotate(self, rotate):
        """Sets the rotate of this Page.


        :param rotate: The rotate of this Page.  # noqa: E501
        :type: float
        """

        self._rotate = rotate

    @property
    def thumbnail(self):
        """Gets the thumbnail of this Page.  # noqa: E501


        :return: The thumbnail of this Page.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """Sets the thumbnail of this Page.


        :param thumbnail: The thumbnail of this Page.  # noqa: E501
        :type: str
        """
        if thumbnail is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', thumbnail):  # noqa: E501
            raise ValueError(r"Invalid value for `thumbnail`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._thumbnail = thumbnail

    @property
    def page_url(self):
        """Gets the page_url of this Page.  # noqa: E501


        :return: The page_url of this Page.  # noqa: E501
        :rtype: str
        """
        return self._page_url

    @page_url.setter
    def page_url(self, page_url):
        """Sets the page_url of this Page.


        :param page_url: The page_url of this Page.  # noqa: E501
        :type: str
        """

        self._page_url = page_url

    @property
    def image_format(self):
        """Gets the image_format of this Page.  # noqa: E501


        :return: The image_format of this Page.  # noqa: E501
        :rtype: str
        """
        return self._image_format

    @image_format.setter
    def image_format(self, image_format):
        """Sets the image_format of this Page.


        :param image_format: The image_format of this Page.  # noqa: E501
        :type: str
        """

        self._image_format = image_format

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Page, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Page):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.doc_log import DocLog  # noqa: F401,E501
from pdf4me.model.document import Document  # noqa: F401,E501
from pdf4me.model.integration_call import IntegrationCall  # noqa: F401,E501


class ApiCallDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'str',
        'application_id': 'str',
        'application_name': 'str',
        'job_id_ext': 'str',
        'integration_calls': 'list[IntegrationCall]',
        'feature': 'str',
        'status': 'str',
        'error_code': 'str',
        'ip_address': 'str',
        'api_cost': 'int',
        'call_type': 'str',
        'user_agent': 'str',
        'in_documents': 'list[Document]',
        'out_documents': 'list[Document]',
        'pages': 'int',
        'doc_size': 'int',
        'duration_ms': 'int',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'action_req_json': 'str',
        'action_res_json': 'str',
        'error_details': 'str',
        'doc_logs': 'list[DocLog]'
    }

    attribute_map = {
        'job_id': 'jobId',
        'application_id': 'applicationId',
        'application_name': 'applicationName',
        'job_id_ext': 'jobIdExt',
        'integration_calls': 'integrationCalls',
        'feature': 'feature',
        'status': 'status',
        'error_code': 'ErrorCode',
        'ip_address': 'ipAddress',
        'api_cost': 'apiCost',
        'call_type': 'callType',
        'user_agent': 'userAgent',
        'in_documents': 'inDocuments',
        'out_documents': 'outDocuments',
        'pages': 'pages',
        'doc_size': 'docSize',
        'duration_ms': 'durationMS',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'action_req_json': 'actionReqJson',
        'action_res_json': 'actionResJson',
        'error_details': 'errorDetails',
        'doc_logs': 'docLogs'
    }

    def __init__(self, job_id=None, application_id=None, application_name=None, job_id_ext=None, integration_calls=None, feature=None, status=None, error_code=None, ip_address=None, api_cost=None, call_type=None, user_agent=None, in_documents=None, out_documents=None, pages=None, doc_size=None, duration_ms=None, start_time=None, end_time=None, action_req_json=None, action_res_json=None, error_details=None, doc_logs=None):  # noqa: E501
        """ApiCallDetail - a model defined in Swagger"""  # noqa: E501

        self._job_id = None
        self._application_id = None
        self._application_name = None
        self._job_id_ext = None
        self._integration_calls = None
        self._feature = None
        self._status = None
        self._error_code = None
        self._ip_address = None
        self._api_cost = None
        self._call_type = None
        self._user_agent = None
        self._in_documents = None
        self._out_documents = None
        self._pages = None
        self._doc_size = None
        self._duration_ms = None
        self._start_time = None
        self._end_time = None
        self._action_req_json = None
        self._action_res_json = None
        self._error_details = None
        self._doc_logs = None
        self.discriminator = None

        if job_id is not None:
            self.job_id = job_id
        if application_id is not None:
            self.application_id = application_id
        if application_name is not None:
            self.application_name = application_name
        if job_id_ext is not None:
            self.job_id_ext = job_id_ext
        if integration_calls is not None:
            self.integration_calls = integration_calls
        if feature is not None:
            self.feature = feature
        if status is not None:
            self.status = status
        if error_code is not None:
            self.error_code = error_code
        if ip_address is not None:
            self.ip_address = ip_address
        if api_cost is not None:
            self.api_cost = api_cost
        if call_type is not None:
            self.call_type = call_type
        if user_agent is not None:
            self.user_agent = user_agent
        if in_documents is not None:
            self.in_documents = in_documents
        if out_documents is not None:
            self.out_documents = out_documents
        if pages is not None:
            self.pages = pages
        if doc_size is not None:
            self.doc_size = doc_size
        if duration_ms is not None:
            self.duration_ms = duration_ms
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if action_req_json is not None:
            self.action_req_json = action_req_json
        if action_res_json is not None:
            self.action_res_json = action_res_json
        if error_details is not None:
            self.error_details = error_details
        if doc_logs is not None:
            self.doc_logs = doc_logs

    @property
    def job_id(self):
        """Gets the job_id of this ApiCallDetail.  # noqa: E501


        :return: The job_id of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this ApiCallDetail.


        :param job_id: The job_id of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def application_id(self):
        """Gets the application_id of this ApiCallDetail.  # noqa: E501


        :return: The application_id of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this ApiCallDetail.


        :param application_id: The application_id of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._application_id = application_id

    @property
    def application_name(self):
        """Gets the application_name of this ApiCallDetail.  # noqa: E501


        :return: The application_name of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._application_name

    @application_name.setter
    def application_name(self, application_name):
        """Sets the application_name of this ApiCallDetail.


        :param application_name: The application_name of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._application_name = application_name

    @property
    def job_id_ext(self):
        """Gets the job_id_ext of this ApiCallDetail.  # noqa: E501


        :return: The job_id_ext of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._job_id_ext

    @job_id_ext.setter
    def job_id_ext(self, job_id_ext):
        """Sets the job_id_ext of this ApiCallDetail.


        :param job_id_ext: The job_id_ext of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._job_id_ext = job_id_ext

    @property
    def integration_calls(self):
        """Gets the integration_calls of this ApiCallDetail.  # noqa: E501


        :return: The integration_calls of this ApiCallDetail.  # noqa: E501
        :rtype: list[IntegrationCall]
        """
        return self._integration_calls

    @integration_calls.setter
    def integration_calls(self, integration_calls):
        """Sets the integration_calls of this ApiCallDetail.


        :param integration_calls: The integration_calls of this ApiCallDetail.  # noqa: E501
        :type: list[IntegrationCall]
        """

        self._integration_calls = integration_calls

    @property
    def feature(self):
        """Gets the feature of this ApiCallDetail.  # noqa: E501


        :return: The feature of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._feature

    @feature.setter
    def feature(self, feature):
        """Sets the feature of this ApiCallDetail.


        :param feature: The feature of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._feature = feature

    @property
    def status(self):
        """Gets the status of this ApiCallDetail.  # noqa: E501


        :return: The status of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ApiCallDetail.


        :param status: The status of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def error_code(self):
        """Gets the error_code of this ApiCallDetail.  # noqa: E501


        :return: The error_code of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this ApiCallDetail.


        :param error_code: The error_code of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    @property
    def ip_address(self):
        """Gets the ip_address of this ApiCallDetail.  # noqa: E501


        :return: The ip_address of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this ApiCallDetail.


        :param ip_address: The ip_address of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def api_cost(self):
        """Gets the api_cost of this ApiCallDetail.  # noqa: E501


        :return: The api_cost of this ApiCallDetail.  # noqa: E501
        :rtype: int
        """
        return self._api_cost

    @api_cost.setter
    def api_cost(self, api_cost):
        """Sets the api_cost of this ApiCallDetail.


        :param api_cost: The api_cost of this ApiCallDetail.  # noqa: E501
        :type: int
        """

        self._api_cost = api_cost

    @property
    def call_type(self):
        """Gets the call_type of this ApiCallDetail.  # noqa: E501


        :return: The call_type of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._call_type

    @call_type.setter
    def call_type(self, call_type):
        """Sets the call_type of this ApiCallDetail.


        :param call_type: The call_type of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._call_type = call_type

    @property
    def user_agent(self):
        """Gets the user_agent of this ApiCallDetail.  # noqa: E501


        :return: The user_agent of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """Sets the user_agent of this ApiCallDetail.


        :param user_agent: The user_agent of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._user_agent = user_agent

    @property
    def in_documents(self):
        """Gets the in_documents of this ApiCallDetail.  # noqa: E501


        :return: The in_documents of this ApiCallDetail.  # noqa: E501
        :rtype: list[Document]
        """
        return self._in_documents

    @in_documents.setter
    def in_documents(self, in_documents):
        """Sets the in_documents of this ApiCallDetail.


        :param in_documents: The in_documents of this ApiCallDetail.  # noqa: E501
        :type: list[Document]
        """

        self._in_documents = in_documents

    @property
    def out_documents(self):
        """Gets the out_documents of this ApiCallDetail.  # noqa: E501


        :return: The out_documents of this ApiCallDetail.  # noqa: E501
        :rtype: list[Document]
        """
        return self._out_documents

    @out_documents.setter
    def out_documents(self, out_documents):
        """Sets the out_documents of this ApiCallDetail.


        :param out_documents: The out_documents of this ApiCallDetail.  # noqa: E501
        :type: list[Document]
        """

        self._out_documents = out_documents

    @property
    def pages(self):
        """Gets the pages of this ApiCallDetail.  # noqa: E501


        :return: The pages of this ApiCallDetail.  # noqa: E501
        :rtype: int
        """
        return self._pages

    @pages.setter
    def pages(self, pages):
        """Sets the pages of this ApiCallDetail.


        :param pages: The pages of this ApiCallDetail.  # noqa: E501
        :type: int
        """

        self._pages = pages

    @property
    def doc_size(self):
        """Gets the doc_size of this ApiCallDetail.  # noqa: E501


        :return: The doc_size of this ApiCallDetail.  # noqa: E501
        :rtype: int
        """
        return self._doc_size

    @doc_size.setter
    def doc_size(self, doc_size):
        """Sets the doc_size of this ApiCallDetail.


        :param doc_size: The doc_size of this ApiCallDetail.  # noqa: E501
        :type: int
        """

        self._doc_size = doc_size

    @property
    def duration_ms(self):
        """Gets the duration_ms of this ApiCallDetail.  # noqa: E501


        :return: The duration_ms of this ApiCallDetail.  # noqa: E501
        :rtype: int
        """
        return self._duration_ms

    @duration_ms.setter
    def duration_ms(self, duration_ms):
        """Sets the duration_ms of this ApiCallDetail.


        :param duration_ms: The duration_ms of this ApiCallDetail.  # noqa: E501
        :type: int
        """

        self._duration_ms = duration_ms

    @property
    def start_time(self):
        """Gets the start_time of this ApiCallDetail.  # noqa: E501


        :return: The start_time of this ApiCallDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this ApiCallDetail.


        :param start_time: The start_time of this ApiCallDetail.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this ApiCallDetail.  # noqa: E501


        :return: The end_time of this ApiCallDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this ApiCallDetail.


        :param end_time: The end_time of this ApiCallDetail.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def action_req_json(self):
        """Gets the action_req_json of this ApiCallDetail.  # noqa: E501


        :return: The action_req_json of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._action_req_json

    @action_req_json.setter
    def action_req_json(self, action_req_json):
        """Sets the action_req_json of this ApiCallDetail.


        :param action_req_json: The action_req_json of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._action_req_json = action_req_json

    @property
    def action_res_json(self):
        """Gets the action_res_json of this ApiCallDetail.  # noqa: E501


        :return: The action_res_json of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._action_res_json

    @action_res_json.setter
    def action_res_json(self, action_res_json):
        """Sets the action_res_json of this ApiCallDetail.


        :param action_res_json: The action_res_json of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._action_res_json = action_res_json

    @property
    def error_details(self):
        """Gets the error_details of this ApiCallDetail.  # noqa: E501


        :return: The error_details of this ApiCallDetail.  # noqa: E501
        :rtype: str
        """
        return self._error_details

    @error_details.setter
    def error_details(self, error_details):
        """Sets the error_details of this ApiCallDetail.


        :param error_details: The error_details of this ApiCallDetail.  # noqa: E501
        :type: str
        """

        self._error_details = error_details

    @property
    def doc_logs(self):
        """Gets the doc_logs of this ApiCallDetail.  # noqa: E501


        :return: The doc_logs of this ApiCallDetail.  # noqa: E501
        :rtype: list[DocLog]
        """
        return self._doc_logs

    @doc_logs.setter
    def doc_logs(self, doc_logs):
        """Sets the doc_logs of this ApiCallDetail.


        :param doc_logs: The doc_logs of this ApiCallDetail.  # noqa: E501
        :type: list[DocLog]
        """

        self._doc_logs = doc_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApiCallDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiCallDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException
from pdf4me.model import ReadBarcodes


class BarcodeClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def read_barcodes(self, read_barcodes):
        """The predefined stamp is carried out.

        :param read_barcodes: read barcode configuration
        :type read_barcodes: ReadBarcodes
        :return: ReadBarcodeRes, contains the barcode
        """

        # check read_barcodes validity
        self.__check_read_barcodes_object_validity(read_barcodes)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=read_barcodes,
                                                                   controller='Barcode/ReadBarcodes')

        return res

    def read_barcodes_by_type(self, barcode_type, file):
        """Reads barcodes from the file based on the barcode type

        :param barcode_type: barcode type
        :type barcode_type: str: ( 'all','unknown','code11','code39','code93','code128','codabar','inter2of5',
                                'patchcode','ean8','upce','ean13','upca','plus2','plus5','pdf417','datamatrix','qrcode',
                                'postnet','planet','rm4scc','australiapost','intelligentmail','code39extended',
                                'microqrcode','all_2d','pharmacode','ucc128','rss14','rsslimited','rssexpanded','all_1d')
        :param file: to be read barcode form
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('barcodeType', barcode_type)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='Barcode/ReadBarcodesByType')

    def __check_read_barcodes_object_validity(self, read_barcodes):
        """checks whether the stamp object contains the essential information to be
        processed by the server."""

        if read_barcodes is None:
            raise Pdf4meClientException('The read_barcodes parameter cannot be None.')
        elif read_barcodes.document is None or read_barcodes.document.doc_data is None:
            raise Pdf4meClientException('The stamp document cannot be None.')
        # elif read_barcodes.barcode_action is None:
        #     raise Pdf4meClientException('The stamp_action cannot be None.')



from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException
from pdf4me.model import Optimize


class OptimizeClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def optimize(self, optimize):
        """The predefined optimization is carried out.

        :param optimize: optimization configuration
        :type optimize: Optimize
        :return: OptimizeRes, contains optimized PDF
        """

        # check optimize validity
        self.__check_optimize_object_validity(optimize)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=optimize,
                                                                   controller='Optimize/Optimize')

        return res

    def optimize_by_profile(self, profile, file):
        """The provided file will be optimized w.r.t the chosen profile. For instance if the profile 'max' has been
        selected, the resulting PDF will be optimized for maximal memory size reduction.

        :param profile: optimization profile (e.g. 'max' for maximal compression)
        :type profile: str
        :param file: to be optimized
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of resulting file, can be directly written to file on disk
        """

        streams = [('file', file)]
        params = [('profile', profile)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='Optimize/OptimizeByProfile')

    def __check_optimize_object_validity(self, optimize):
        """Checks whether the optimize object contains the essential information to be
                processed by the server."""

        if optimize is None:
            raise Pdf4meClientException('The optimize parameter cannot be None.')
        elif optimize.document is None or optimize.document.doc_data is None:
            raise Pdf4meClientException('The optimize document cannot be None.')
        elif optimize.optimize_action is None:
            raise Pdf4meClientException('The optimize_action cannot be None.')
        elif optimize.optimize_action.use_profile != True:
            raise Pdf4meClientException('The use_profile parameter of optimize_action has to be set to true.')



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class OcrAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'stapel': 'str',
        'businesss_card_reco': 'bool',
        'full_text_search': 'bool',
        'output_type': 'str'
    }

    attribute_map = {
        'stapel': 'stapel',
        'businesss_card_reco': 'businesssCardReco',
        'full_text_search': 'fullTextSearch',
        'output_type': 'outputType'
    }

    def __init__(self, stapel=None, businesss_card_reco=None, full_text_search=None, output_type=None):  # noqa: E501
        """OcrAction - a model defined in Swagger"""  # noqa: E501

        self._stapel = None
        self._businesss_card_reco = None
        self._full_text_search = None
        self._output_type = None
        self.discriminator = None

        if stapel is not None:
            self.stapel = stapel
        if businesss_card_reco is not None:
            self.businesss_card_reco = businesss_card_reco
        if full_text_search is not None:
            self.full_text_search = full_text_search
        if output_type is not None:
            self.output_type = output_type

    @property
    def stapel(self):
        """Gets the stapel of this OcrAction.  # noqa: E501


        :return: The stapel of this OcrAction.  # noqa: E501
        :rtype: str
        """
        return self._stapel

    @stapel.setter
    def stapel(self, stapel):
        """Sets the stapel of this OcrAction.


        :param stapel: The stapel of this OcrAction.  # noqa: E501
        :type: str
        """

        self._stapel = stapel

    @property
    def businesss_card_reco(self):
        """Gets the businesss_card_reco of this OcrAction.  # noqa: E501


        :return: The businesss_card_reco of this OcrAction.  # noqa: E501
        :rtype: bool
        """
        return self._businesss_card_reco

    @businesss_card_reco.setter
    def businesss_card_reco(self, businesss_card_reco):
        """Sets the businesss_card_reco of this OcrAction.


        :param businesss_card_reco: The businesss_card_reco of this OcrAction.  # noqa: E501
        :type: bool
        """

        self._businesss_card_reco = businesss_card_reco

    @property
    def full_text_search(self):
        """Gets the full_text_search of this OcrAction.  # noqa: E501


        :return: The full_text_search of this OcrAction.  # noqa: E501
        :rtype: bool
        """
        return self._full_text_search

    @full_text_search.setter
    def full_text_search(self, full_text_search):
        """Sets the full_text_search of this OcrAction.


        :param full_text_search: The full_text_search of this OcrAction.  # noqa: E501
        :type: bool
        """

        self._full_text_search = full_text_search

    @property
    def output_type(self):
        """Gets the output_type of this OcrAction.  # noqa: E501


        :return: The output_type of this OcrAction.  # noqa: E501
        :rtype: str
        """
        return self._output_type

    @output_type.setter
    def output_type(self, output_type):
        """Sets the output_type of this OcrAction.


        :param output_type: The output_type of this OcrAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "txt", "docx", "xlsx", "pptx", "pdfSearchable", "xml", "rtf", "rtt", "vcf", "json"]  # noqa: E501
        if output_type not in allowed_values:
            raise ValueError(
                "Invalid value for `output_type` ({0}), must be one of {1}"  # noqa: E501
                .format(output_type, allowed_values)
            )

        self._output_type = output_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OcrAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OcrAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import json
import inflection


class JsonConverter(object):

    def dump(self, element):
        """Dumps an object to a json formatted string,
        in the process all snake_case keys are converted to camelCase.

        :param element: object
        :type element: object
        :return: json formatted string, representing the the object element
        """

        json_string = json.dumps(element, default=self.__jsonDefault)

        # convert snake_case to camelCase

        # load jsonString into jsonObject, while doing so, convert all keys to camelCase
        json_object = json.loads(json_string, object_hook=self.__convert_keys_to_camelCase)
        # dump back to jsonString
        json_string = json.dumps(json_object)

        return json_string

    def load(self, element):
        """Loads an object given a json formatted string,
        in the process all camelCase keys are converted to snake_case.

        :param element: json formatted string
        :type element: str
        :return: object, representing json formatted string
        """

        return json.loads(element, object_hook=self.__convert_keys_to_snake_case)

    def __jsonDefault(self, obj):
        """Aids to dump custom objects to json, by converting them to a dictionary,
        removing all fields which are set to None in the process."""
        return dict(filter(lambda item: item[1] is not None, obj.__dict__.items()))

    def __convert_keys_to_camelCase(self, obj):
        """Converts all keys to camelCase."""
        # to prevent iterating over keys twice,
        # as they are newly added, they are also added to the iterator
        number_of_keys = 0
        for key in obj.keys():
            number_of_keys += 1
        current = 1
        # replace keys
        for key in obj.keys():
            if current > number_of_keys:
                break
            current += 1
            # camelize and remove leading '_'
            new_key = inflection.camelize(key)[1:]
            if new_key != key:
                obj[new_key] = obj[key]
                del obj[key]
        return obj

    def __convert_keys_to_snake_case(self, obj):
        """Converts all keys to snake_case."""
        # to prevent iterating over keys twice,
        # as they are newly added, they are also added to the iterator
        number_of_keys = 0
        for key in obj.keys():
            number_of_keys += 1
        current = 1
        # replace keys
        for key in obj.keys():
            if current > number_of_keys:
                break
            current += 1
            # switch to snake_case
            new_key = inflection.underscore(key)
            if new_key != key:
                obj[new_key] = obj[key]
                del obj[key]
        return obj
